Storage

Enum Storage 

pub enum Storage {
    Bytes(Bytes),
    BytesMut(BytesMut),
    Params(Params),
    KVLines(KVLines),
    File(PathBuf),
    LocalFile(PathBuf),
}
Storage buffer for metadata and payload.

Variants



Bytes(Bytes)

Return data as a bytes::Bytes buffer.



BytesMut(BytesMut)

Return data as a bytes::BytesMut buffer.



Params(Params)

Return data as a parsed Params buffer.



KVLines(KVLines)

Return data as a parsed KVLines buffer.



File(PathBuf)

A file whose location was requested by the application.



LocalFile(PathBuf)

A file whose location was specified by DDMW. It is the responsibility of the application to move the file from its current location to an application specific storage, or delete the file if it is not relevant.