pub enum Type {
Sender,
Receiver,
}
Denote whether a node is on the sender or receiver side of the hardware
data diode.
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
The associated error which can be returned from parsing.
Parses a string s to return a value of this type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.