Enum ddmw_client::err::Error[][src]

pub enum Error {
    Blather(String),
    IO(String),
    ServerError(Params),
    BadState(String),
    Disconnected,
    BadInput(String),
    BadParams(String),
    InvalidCredentials(String),
    MissingData(String),
    Parse(String),
    Figment(String),
}
ddmw-client error values.

Variants

Blather(String)

An error occurred in the Blather communications library.

Tuple Fields of Blather

0: String
IO(String)

A std::io or tokio::io error occurred.

Tuple Fields of IO

0: String
ServerError(Params)

A DDMW core server return Fail. The Params buffer contains details about the error.

Tuple Fields of ServerError

0: Params
BadState(String)

A state was entered which was unexpected. This can mean that the client expected to receive something from the server, but received something else, which may technically have been okay under different circumstances.

Tuple Fields of BadState

0: String
Disconnected

A server disconnected or the client is in a disconnected state.

BadInput(String)

A function or method was called with an invalid/unknown input.

Tuple Fields of BadInput

0: String
BadParams(String)

A function or method was called with incomplete or ambiguous parameters.

Tuple Fields of BadParams

0: String
InvalidCredentials(String)

Authentication was requested, but the authentication context is invalid (missing or invalid data).

Tuple Fields of InvalidCredentials

0: String
MissingData(String)

Some expected data is missing.

Tuple Fields of MissingData

0: String
Parse(String)

Tuple Fields of Parse

0: String
Figment(String)

Tuple Fields of Figment

0: String

Implementations