pub enum ModPerms {
Set(HashSet<String>),
Grant(HashSet<String>),
Revoke(HashSet<String>),
GrantRevoke(HashSet<String>, HashSet<String>),
}Expand description
Enumeration of account permission change methods.
Variants
Set(HashSet<String>)
Reset the account’s permissions to the ones passed in the supplied HashSet.
Grant(HashSet<String>)
Add the supplied permissions to the account’s permissions. Collisions are ignored.
Revoke(HashSet<String>)
Remove the supplied permissions from the account’s permissions. Removal of permissions the account doesn’t have are silently ignored.
GrantRevoke(HashSet<String>, HashSet<String>)
First grant permissions to the account, then remove permissions.