Enum ddmw_client::mgmt::acc::ModPerms[][src]

pub enum ModPerms {
    Set(HashSet<String>),
    Grant(HashSet<String>),
    Revoke(HashSet<String>),
    GrantRevoke(HashSet<String>, HashSet<String>),
}
Enumeration of account permission change methods.

Variants

Reset the account’s permissions to the ones passed in the supplied HashSet.

Tuple Fields of Set

0: HashSet<String>
Grant(HashSet<String>)

Add the supplied permissions to the account’s permissions. Collisions are ignored.

Tuple Fields of Grant

0: HashSet<String>
Revoke(HashSet<String>)

Remove the supplied permissions from the account’s permissions. Removal of permissions the account doesn’t have are silently ignored.

Tuple Fields of Revoke

0: HashSet<String>
GrantRevoke(HashSet<String>, HashSet<String>)

First grant permissions to the account, then remove permissions.

Tuple Fields of GrantRevoke

0: HashSet<String>1: HashSet<String>