Enum ddmw_client::mgmt::acc::ModPerms [−][src]
pub enum ModPerms {
Set(HashSet<String>),
Grant(HashSet<String>),
Revoke(HashSet<String>),
GrantRevoke(HashSet<String>, HashSet<String>),
}Expand description
Enumeration of account permission change methods.
Variants
Reset the account’s permissions to the ones passed in the supplied HashSet.
Add the supplied permissions to the account’s permissions. Collisions are ignored.
Remove the supplied permissions from the account’s permissions. Removal of permissions the account doesn’t have are silently ignored.
First grant permissions to the account, then remove permissions.