Enum ddmw_client::msg::recv::Storage[][src]

pub enum Storage {
    Bytes(Bytes),
    BytesMut(BytesMut),
    Params(Params),
    KVLines(KVLines),
    File(PathBuf),
    LocalFile(PathBuf),
}
Storage buffer for metadata and payload.

Variants

Bytes(Bytes)

Return data as a bytes::Bytes buffer.

Tuple Fields of Bytes

0: Bytes
BytesMut(BytesMut)

Return data as a bytes::BytesMut buffer.

Tuple Fields of BytesMut

0: BytesMut
Params(Params)

Return data as a parsed Params buffer.

Tuple Fields of Params

0: Params
KVLines(KVLines)

Return data as a parsed KVLines buffer.

Tuple Fields of KVLines

0: KVLines
File(PathBuf)

A file whose location was requested by the application.

Tuple Fields of File

0: PathBuf
LocalFile(PathBuf)

A file whose location was specified by DDMW. It is the responsibility of the application to move the file from its current location to an application specific storage, or delete the file if it is not relevant.

Tuple Fields of LocalFile

0: PathBuf